@@ -24,7 +24,7 @@
 
 #define _FILE_OFFSET_BITS   64
 
-#define VERSION "0.5"
+#define VERSION "0.5.1"
 
 #define SUB_BUFFER_MAX		53220 
 
@@ -1967,7 +1967,7 @@ That makes: 0 0 0 1 1 1 1 0 = 0x1e
 							fprintf(stdout,\
 							"sub_size=%d\n\
 	bytes_send=%d\n\
-	available_space=%d
+	available_space=%d\n\
 	bytes_left=%d\n\
 	bytes_free=%d\n\
 	header_mode=%d\n\
@@ -3044,6 +3044,9 @@ return b;
 
 
 static int max_bits_in_line;
+static int reported_max_bits_flag;
+static int size_errors;
+
 
 //#define TEST_PIC
 int dvd_encode()
@@ -3084,6 +3087,8 @@ if(debug_flag)
 	spts / 90000, sd / 90000, xd, yd, x0, y0);
 	}
 	
+oddp = 0;
+
 xstart = x0;
 xsize = xd;
 ystart = y0;
@@ -3232,7 +3237,7 @@ for(y = 0; y < yd; y++)
 		store_nibble(0);
 		store_nibble(0);
 		store_nibble(0);
-		store_nibble(icptr[idx]);
+		store_nibble(icptr[idx]); /* color 0-3, high 2 bits zero of this nibble */
 
 		if(odd) odd_line_nibbles += 4;
 		else even_line_nibbles += 4;
@@ -3273,14 +3278,24 @@ for(y = 0; y < yd; y++)
 //	fprintf(stderr, "max_bits_in_line=%d\n", max_bits_in_line);
 	if(max_bits_in_line > 1440)
 		{
-		fprintf(stderr,\
-		"dvd_encode(): bitmap too wide? max_bits_in_line=%d > 1440, aborting\n",\
-		max_bits_in_line);
+		if(! reported_max_bits_flag)
+			{
+			size_errors++;
 
+			fprintf(stderr,\
+			"dvd_encode(): bitmap too wide? max_bits_in_line=%d > 1440 size_errors=%d, aborting\n",\
+			max_bits_in_line, size_errors);
+			reported_max_bits_flag = 1;
+			fprintf(stderr,\
+			"This is a DVD compatibility problem (too much detail in a line)\n\
+try reformatting the text for this bitmap\n");
+
+			}
+
+//amaroo3 frame8422.bmp font 22 v0.04 h0.02 have to sort this out
 		exit(1);	
 		}
 
-
 	odd = 1 - odd;
 	} /* end for y (all lines in an img) */ 
 
