@@ -789,7 +789,8 @@ if(!type)
 				bpal[b].r = h2d(cbuf + a); a += 2;
 				bpal[b].g = h2d(cbuf + a); a += 2;
 				bpal[b].b = h2d(cbuf + a); a += 2; 
-				if(debug > 3) fprintf(stderr, "pal: %d #%.2x%.2x%.2x\n", b, bpal[b].r, bpal[b].g, bpal[b].b);
+//				if(debug > 3)
+fprintf(stderr, "pal: %d #%.2x%.2x%.2x\n", b, bpal[b].r, bpal[b].g, bpal[b].b);
 				} 
 			}
 		fclose(fdo);
